
# Type: molecular activity_has input




URI: [biolink:molecular_activity_has_input](https://w3id.org/biolink/vocab/molecular_activity_has_input)


## Domain and Range

[MolecularActivity](MolecularActivity.md) ->  <sub>0..*</sub> [ChemicalSubstance](ChemicalSubstance.md)

## Parents

 *  is_a: [has input](has_input.md)

## Children


## Used by

 * [MolecularActivity](MolecularActivity.md)
